@@ -62,8 +62,6 @@ class SwaggerGenerator(Blueprint):
         @self.get(documentation_url)
         def get_openapi_json():
             openapi = self.generate_openapi_json()
-            with open("tesjson","w") as f:
-                json.dump(openapi, f, indent=4)
             return jsonify(openapi)
     
     def create_init_template(
@@ -184,16 +182,14 @@ class SwaggerGenerator(Blueprint):
         pydantic_model = create_model(
             key,
             **{
-                key: (param_object.dtype, param_object.default)
+                key: (param_object.dtype, param_object)
             }
         )
         schema = pydantic_model.schema(ref_template="#/components/schemas/{model}")
         schema["type"] = self.get_schema_dtype(param_object.dtype)
-        if param_object.description:
-            schema["description"] = param_object.description
         return schema
 
-    def generate_parameter_schema(self, paired_params: Dict[str, ParamsType]):
+    def generate_parameter_schema(self, paired_params: Dict[str, ParamSignature]):
         schemas = []
         definitions = {}
         for k, p in paired_params.items():
@@ -241,16 +237,17 @@ class SwaggerGenerator(Blueprint):
             self,
             name: str,
             paired_params: Dict[str, ParamSignature],
-            params_type: FormType
+            params_type: FormType,
+            force_type: Optional[Any] = None,
         ):
         all_forms = []
         i = 0
         for k, p in paired_params.items():
-            po = p.param_object
-            if type(po) == params_type:
+            if type(p.param_object) == params_type:
+                ptype = force_type if force_type else p._type
                 ss = create_model(
-                    name+"_"+po._type.value+f"-{i}",
-                    **{k: (str, p._default)}
+                    name+"_"+p.param_object._type.value+f"-{i}",
+                    **{k: (ptype, p.param_object)}
                 )
                 all_forms.append(
                     ss.schema(ref_template="#/components/schemas/{model}")
@@ -265,7 +262,7 @@ class SwaggerGenerator(Blueprint):
         return self._generate_form_schema(name, paired_params, FormURLEncoded)
 
     def generate_body_file_schema(self, name, paired_params):
-        body_form = self._generate_form_schema(name, paired_params, File)
+        body_form = self._generate_form_schema(name, paired_params, File, str)
         for b in body_form:
             b["properties"][
                 list(b["properties"].keys())[0]
